@@ -21,8 +21,8 @@
 
 #include "belcard_utils.hpp"
 #include "belcard_property.hpp"
-#include <belr/grammarbuilder.hh>
-#include <belr/abnf.hh>
+#include <belr/grammarbuilder.h>
+#include <belr/abnf.h>
 
 #include <string>
 
