@@ -1,44 +1,47 @@
 /*
-	belcard-vcard-tester.cpp
-	Copyright (C) 2015  Belledonne Communications SARL
+    belcard-vcard-tester.cpp
+    Copyright (C) 2015  Belledonne Communications SARL
 
-	This program is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 3 of the License, or
-	(at your option) any later version.
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
-#include <belr/belr.h>
+#include "belcard-tester.hpp"
 #include "belcard/belcard.hpp"
 #include "belcard/belcard_parser.hpp"
 #include "belcard/belcard_utils.hpp"
-#include "belcard-tester.hpp"
+#include <belr/belr.h>
 
 #include <bctoolbox/tester.h>
-#include <iostream>
 #include <fstream>
+#include <iostream>
 #include <sstream>
 #include <string>
 
-using namespace::std;
-using namespace::belr;
-using namespace::belcard;
+using namespace ::std;
+using namespace ::belr;
+using namespace ::belcard;
 
 static string openFile(const char *name) {
-	ifstream istr(bc_tester_res(name), std::ios::binary);
+	char *res = bc_tester_res(name);
+
+	ifstream istr(res, std::ios::binary);
 	if (!istr.is_open()) {
 		BC_FAIL(name);
 	}
 
+	bctbx_free(res);
+
 	stringstream vcardStream;
 	vcardStream << istr.rdbuf();
 	string vcard = vcardStream.str();
@@ -64,12 +67,12 @@ static void vcard_parsing(void) {
 
 	BelCardParser *parser = new BelCardParser();
 	shared_ptr<BelCard> belCard = parser->parseOne(vcard);
-	if (!BC_ASSERT_TRUE(belCard!=NULL)) return;
+	if (!BC_ASSERT_TRUE(belCard != NULL)) return;
 	BC_ASSERT_TRUE(belCard->assertRFCCompliance());
 
 	string vcard2 = belCard->toFoldedString();
 	BC_ASSERT_EQUAL(vcard2.compare(vcard), 0, int, "%d");
-	delete(parser);
+	delete (parser);
 }
 
 static void vcards_parsing(void) {
@@ -77,17 +80,17 @@ static void vcards_parsing(void) {
 
 	BelCardParser *parser = new BelCardParser();
 	shared_ptr<BelCardList> belCards = parser->parse(vcards);
-	if (!BC_ASSERT_TRUE(belCards!=NULL)) return;
+	if (!BC_ASSERT_TRUE(belCards != NULL)) return;
 	BC_ASSERT_EQUAL((unsigned int)belCards->getCards().size(), 2, unsigned int, "%u");
 
 	string vcards2 = belCards->toString();
 	BC_ASSERT_EQUAL(vcards2.compare(vcards), 0, int, "%d");
-	delete(parser);
+	delete (parser);
 }
 
 static void create_vcard_from_api(void) {
 	shared_ptr<BelCard> belCard = BelCard::create<BelCard>();
-	if (!BC_ASSERT_TRUE(belCard!=NULL)) return;
+	if (!BC_ASSERT_TRUE(belCard != NULL)) return;
 	BC_ASSERT_FALSE(belCard->assertRFCCompliance());
 
 	shared_ptr<BelCardFullName> fn = BelCard::create<BelCardFullName>();
@@ -104,22 +107,22 @@ static void create_vcard_from_api(void) {
 	string vcard = belCard->toString();
 	BelCardParser *parser = new BelCardParser();
 	shared_ptr<BelCard> belCard2 = parser->parseOne(vcard);
-	if (!BC_ASSERT_TRUE(belCard2!=NULL)) return;
+	if (!BC_ASSERT_TRUE(belCard2 != NULL)) return;
 	BC_ASSERT_TRUE(belCard2->assertRFCCompliance());
 	string vcard2 = belCard2->toString();
 	BC_ASSERT_EQUAL(vcard.compare(vcard2), 0, unsigned, "%u");
-	delete(parser);
+	delete (parser);
 }
 
 static void property_sort_using_pref_param(void) {
 	shared_ptr<BelCard> belCard = BelCard::create<BelCard>();
-	BC_ASSERT_TRUE(belCard!=NULL);
+	BC_ASSERT_TRUE(belCard != NULL);
 
 	shared_ptr<BelCardImpp> impp1 = BelCardImpp::parse("IMPP;TYPE=home;PREF=2:sip:viish@sip.linphone.org\r\n");
-	BC_ASSERT_TRUE(impp1!=NULL);
+	BC_ASSERT_TRUE(impp1 != NULL);
 
 	shared_ptr<BelCardImpp> impp2 = BelCardImpp::parse("IMPP;PREF=1;TYPE=work:sip:sylvain@sip.linphone.org\r\n");
-	BC_ASSERT_TRUE(impp2!=NULL);
+	BC_ASSERT_TRUE(impp2 != NULL);
 
 	belCard->addImpp(impp1);
 	belCard->addImpp(impp2);
@@ -138,20 +141,12 @@ static void property_sort_using_pref_param(void) {
 }
 
 static test_t tests[] = {
-	TEST_NO_TAG("Folding", folding),
-	TEST_NO_TAG("Unfolding", unfolding),
-	TEST_NO_TAG("VCard parsing", vcard_parsing),
-	TEST_NO_TAG("VCards parsing", vcards_parsing),
-	TEST_NO_TAG("VCard created from scratch", create_vcard_from_api),
-	TEST_NO_TAG("Property sort using pref param", property_sort_using_pref_param),
+    TEST_NO_TAG("Folding", folding),
+    TEST_NO_TAG("Unfolding", unfolding),
+    TEST_NO_TAG("VCard parsing", vcard_parsing),
+    TEST_NO_TAG("VCards parsing", vcards_parsing),
+    TEST_NO_TAG("VCard created from scratch", create_vcard_from_api),
+    TEST_NO_TAG("Property sort using pref param", property_sort_using_pref_param),
 };
 
-test_suite_t vcard_test_suite = {
-	"VCard",
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	sizeof(tests) / sizeof(tests[0]),
-	tests
-};
+test_suite_t vcard_test_suite = {"VCard", NULL, NULL, NULL, NULL, sizeof(tests) / sizeof(tests[0]), tests, 0, 0};
